@@ -512,9 +512,11 @@ class PreseemNetworkMetadataModel(object):
             elif lobj is None and rattrs:
                 diffs.append((key, None, rattrs))
             elif robj and lobj and lattrs != rattrs:
-                diffs.append(
-                    (key, {x: y
-                           for x, y in lattrs.items() if rattrs.get(x) != y},
-                     {x: y
-                      for x, y in rattrs.items() if lattrs.get(x) != y}))
+                diffs.append((key, {
+                    x: y
+                    for x, y in lattrs.items() if rattrs.get(x) != y
+                }, {
+                    x: y
+                    for x, y in rattrs.items() if lattrs.get(x) != y
+                }))
         return diffs
